##  Step 5: Enable the IdP
If the test is successful, enable the IdP for the workspace.
**Caution**
Activating an IdP for a workspace automatically deactivates any previously configured non-self-service SSO setups on the SAP LeanIX side. Once deactivated, you can't reactivate this SSO configuration yourself. Restoring access requires assistance from the support team.
After activation, do the following:
  1. Wait a few minutes. Usually, users have access immediately.
  2. Deactivate or remove the legacy SSO configuration in your IdP.
